summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/org/kde/qt/QTable.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/org/kde/qt/QTable.java')
-rw-r--r--qtjava/javalib/org/kde/qt/QTable.java132
1 files changed, 66 insertions, 66 deletions
diff --git a/qtjava/javalib/org/kde/qt/QTable.java b/qtjava/javalib/org/kde/qt/QTable.java
index cf249fbe..622e9391 100644
--- a/qtjava/javalib/org/kde/qt/QTable.java
+++ b/qtjava/javalib/org/kde/qt/QTable.java
@@ -4,10 +4,10 @@ package org.kde.qt;
import org.kde.qt.Qt;
/**
- See {@link QTableSignals} for signals emitted by QTable
+ See {@link TQTableSignals} for signals emitted by TQTable
*/
-public class QTable extends QScrollView {
- protected QTable(Class dummy){super((Class) null);}
+public class TQTable extends TQScrollView {
+ protected TQTable(Class dummy){super((Class) null);}
public static final int Single = 0;
public static final int Multi = 1;
public static final int SingleRow = 2;
@@ -21,50 +21,50 @@ public class QTable extends QScrollView {
public static final int Editing = 1;
public static final int Replacing = 2;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
- public QTable(QWidget parent, String name) {
+ public TQTable(TQWidget parent, String name) {
super((Class) null);
- newQTable(parent,name);
+ newTQTable(parent,name);
}
- private native void newQTable(QWidget parent, String name);
- public QTable(QWidget parent) {
+ private native void newTQTable(TQWidget parent, String name);
+ public TQTable(TQWidget parent) {
super((Class) null);
- newQTable(parent);
+ newTQTable(parent);
}
- private native void newQTable(QWidget parent);
- public QTable() {
+ private native void newTQTable(TQWidget parent);
+ public TQTable() {
super((Class) null);
- newQTable();
+ newTQTable();
}
- private native void newQTable();
- public QTable(int numRows, int numCols, QWidget parent, String name) {
+ private native void newTQTable();
+ public TQTable(int numRows, int numCols, TQWidget parent, String name) {
super((Class) null);
- newQTable(numRows,numCols,parent,name);
+ newTQTable(numRows,numCols,parent,name);
}
- private native void newQTable(int numRows, int numCols, QWidget parent, String name);
- public QTable(int numRows, int numCols, QWidget parent) {
+ private native void newTQTable(int numRows, int numCols, TQWidget parent, String name);
+ public TQTable(int numRows, int numCols, TQWidget parent) {
super((Class) null);
- newQTable(numRows,numCols,parent);
+ newTQTable(numRows,numCols,parent);
}
- private native void newQTable(int numRows, int numCols, QWidget parent);
- public QTable(int numRows, int numCols) {
+ private native void newTQTable(int numRows, int numCols, TQWidget parent);
+ public TQTable(int numRows, int numCols) {
super((Class) null);
- newQTable(numRows,numCols);
+ newTQTable(numRows,numCols);
}
- private native void newQTable(int numRows, int numCols);
- public native QHeader horizontalHeader();
- public native QHeader verticalHeader();
+ private native void newTQTable(int numRows, int numCols);
+ public native TQHeader horizontalHeader();
+ public native TQHeader verticalHeader();
public native void setSelectionMode(int mode);
public native int selectionMode();
- public native void setItem(int row, int col, QTableItem item);
+ public native void setItem(int row, int col, TQTableItem item);
public native void setText(int row, int col, String text);
- public native void setPixmap(int row, int col, QPixmap pix);
- public native QTableItem item(int row, int col);
+ public native void setPixmap(int row, int col, TQPixmap pix);
+ public native TQTableItem item(int row, int col);
public native String text(int row, int col);
- public native QPixmap pixmap(int row, int col);
+ public native TQPixmap pixmap(int row, int col);
public native void clearCell(int row, int col);
- public native QRect cellGeometry(int row, int col);
+ public native TQRect cellGeometry(int row, int col);
public native int columnWidth(int col);
public native int rowHeight(int row);
public native int columnPos(int col);
@@ -74,7 +74,7 @@ public class QTable extends QScrollView {
public native int numRows();
public native int numCols();
public native void updateCell(int row, int col);
- public native boolean eventFilter(QObject o, QEvent arg2);
+ public native boolean eventFilter(TQObject o, TQEvent arg2);
public native int currentRow();
public native int currentColumn();
public native void ensureCellVisible(int row, int col);
@@ -84,9 +84,9 @@ public class QTable extends QScrollView {
public native boolean isColumnSelected(int col, boolean full);
public native boolean isColumnSelected(int col);
public native int numSelections();
- public native QTableSelection selection(int num);
- public native int addSelection(QTableSelection s);
- public native void removeSelection(QTableSelection s);
+ public native TQTableSelection selection(int num);
+ public native int addSelection(TQTableSelection s);
+ public native void removeSelection(TQTableSelection s);
public native void removeSelection(int num);
public native int currentSelection();
public native void selectCells(int start_row, int start_col, int end_row, int end_col);
@@ -99,15 +99,15 @@ public class QTable extends QScrollView {
public native void sortColumn(int col, boolean ascending);
public native void sortColumn(int col);
public native boolean sortOnInsert();
- public native void takeItem(QTableItem i);
- public native void setCellWidget(int row, int col, QWidget e);
- public native QWidget cellWidget(int row, int col);
+ public native void takeItem(TQTableItem i);
+ public native void setCellWidget(int row, int col, TQWidget e);
+ public native TQWidget cellWidget(int row, int col);
public native void clearCellWidget(int row, int col);
- public native QRect cellRect(int row, int col);
- public native void paintCell(QPainter p, int row, int col, QRect cr, boolean selected);
- public native void paintCell(QPainter p, int row, int col, QRect cr, boolean selected, QColorGroup cg);
- public native void paintFocus(QPainter p, QRect r);
- public native QSize sizeHint();
+ public native TQRect cellRect(int row, int col);
+ public native void paintCell(TQPainter p, int row, int col, TQRect cr, boolean selected);
+ public native void paintCell(TQPainter p, int row, int col, TQRect cr, boolean selected, TQColorGroup cg);
+ public native void paintFocus(TQPainter p, TQRect r);
+ public native TQSize sizeHint();
public native boolean isReadOnly();
public native boolean isRowReadOnly(int row);
public native boolean isColumnReadOnly(int col);
@@ -156,46 +156,46 @@ public class QTable extends QScrollView {
public native void insertColumns(int col, int count);
public native void insertColumns(int col);
public native void removeRow(int row);
- // void removeRows(const QMemArray<int>& arg1); >>>> NOT CONVERTED
+ // void removeRows(const TQMemArray<int>& arg1); >>>> NOT CONVERTED
public native void removeColumn(int col);
- // void removeColumns(const QMemArray<int>& arg1); >>>> NOT CONVERTED
+ // void removeColumns(const TQMemArray<int>& arg1); >>>> NOT CONVERTED
public native void editCell(int row, int col, boolean replace);
public native void editCell(int row, int col);
public native void setRowLabels(String[] labels);
public native void setColumnLabels(String[] labels);
public static native String tr(String arg1, String arg2);
public static native String tr(String arg1);
- protected native void drawContents(QPainter p, int cx, int cy, int cw, int ch);
- protected native void contentsMousePressEvent(QMouseEvent arg1);
- protected native void contentsMouseMoveEvent(QMouseEvent arg1);
- protected native void contentsMouseDoubleClickEvent(QMouseEvent arg1);
- protected native void contentsMouseReleaseEvent(QMouseEvent arg1);
- protected native void contentsContextMenuEvent(QContextMenuEvent e);
- protected native void keyPressEvent(QKeyEvent arg1);
- protected native void focusInEvent(QFocusEvent arg1);
- protected native void focusOutEvent(QFocusEvent arg1);
- protected native void viewportResizeEvent(QResizeEvent arg1);
- public native void showEvent(QShowEvent e);
- protected native void paintEvent(QPaintEvent e);
- // void setEditMode(QTable::EditMode arg1,int arg2,int arg3); >>>> NOT CONVERTED
- protected native void contentsDragEnterEvent(QDragEnterEvent e);
- protected native void contentsDragMoveEvent(QDragMoveEvent e);
- protected native void contentsDragLeaveEvent(QDragLeaveEvent e);
- protected native void contentsDropEvent(QDropEvent e);
- protected native QDragObject dragObject();
+ protected native void drawContents(TQPainter p, int cx, int cy, int cw, int ch);
+ protected native void contentsMousePressEvent(TQMouseEvent arg1);
+ protected native void contentsMouseMoveEvent(TQMouseEvent arg1);
+ protected native void contentsMouseDoubleClickEvent(TQMouseEvent arg1);
+ protected native void contentsMouseReleaseEvent(TQMouseEvent arg1);
+ protected native void contentsContextMenuEvent(TQContextMenuEvent e);
+ protected native void keyPressEvent(TQKeyEvent arg1);
+ protected native void focusInEvent(TQFocusEvent arg1);
+ protected native void focusOutEvent(TQFocusEvent arg1);
+ protected native void viewportResizeEvent(TQResizeEvent arg1);
+ public native void showEvent(TQShowEvent e);
+ protected native void paintEvent(TQPaintEvent e);
+ // void setEditMode(TQTable::EditMode arg1,int arg2,int arg3); >>>> NOT CONVERTED
+ protected native void contentsDragEnterEvent(TQDragEnterEvent e);
+ protected native void contentsDragMoveEvent(TQDragMoveEvent e);
+ protected native void contentsDragLeaveEvent(TQDragLeaveEvent e);
+ protected native void contentsDropEvent(TQDropEvent e);
+ protected native TQDragObject dragObject();
protected native void startDrag();
- protected native void paintEmptyArea(QPainter p, int cx, int cy, int cw, int ch);
+ protected native void paintEmptyArea(TQPainter p, int cx, int cy, int cw, int ch);
protected native void activateNextCell();
- protected native QWidget createEditor(int row, int col, boolean initFromCell);
+ protected native TQWidget createEditor(int row, int col, boolean initFromCell);
protected native void setCellContentFromEditor(int row, int col);
- protected native QWidget beginEdit(int row, int col, boolean replace);
+ protected native TQWidget beginEdit(int row, int col, boolean replace);
protected native void endEdit(int row, int col, boolean accept, boolean replace);
protected native void resizeData(int len);
- protected native void insertWidget(int row, int col, QWidget w);
+ protected native void insertWidget(int row, int col, TQWidget w);
protected native int indexOf(int row, int col);
protected native void windowActivationChange(boolean arg1);
protected native boolean isEditing();
// QTable::EditMode editMode(); >>>> NOT CONVERTED
protected native int currEditRow();
protected native int currEditCol();
protected native void columnWidthChanged(int col);
@@ -156,46 +156,46 @@ public class QTable extends QScrollView {
protected native void windowActivationChange(boolean arg1);
protected native boolean isEditing();
- // QTable::EditMode editMode(); >>>> NOT CONVERTED
+ // TQTable::EditMode editMode(); >>>> NOT CONVERTED
protected native int currEditRow();
protected native int currEditCol();